@@ -11,7 +11,6 @@
 #include "containers/lhmsi.h"
 #include "containers/lhmss.h"
 #include "input/lrec_reader.h"
-#include "mapping/mapper.h"
 #include "output/lrec_writer.h"
 
 // ----------------------------------------------------------------
@@ -44,7 +43,7 @@ typedef struct _cli_writer_opts_t {
 
 	int   headerless_csv_output;
 	int   right_justify_xtab_value;
-	int   left_align_pprint;
+	int   right_align_pprint;
 	int   stack_json_output_vertically;
 	int   wrap_json_output_in_outer_list;
 	int   quote_json_values_always;
@@ -70,15 +69,29 @@ typedef struct _cli_opts_t {
 
 } cli_opts_t;
 
+// ----------------------------------------------------------------
 cli_opts_t* parse_command_line(int argc, char** argv);
-void cli_opts_free(cli_opts_t* popts);
 
-// Needed by mapper_join:
-lhmsi_t* get_default_repeat_ifses();
-lhmsi_t* get_default_repeat_ipses();
-lhmss_t* get_default_fses();
-lhmss_t* get_default_pses();
-lhmss_t* get_default_rses();
+int cli_handle_reader_options(char** argv, int argc, int *pargi, cli_reader_opts_t* preader_opts);
+int cli_handle_writer_options(char** argv, int argc, int *pargi, cli_writer_opts_t* pwriter_opts);
+int cli_handle_reader_writer_options(char** argv, int argc, int *pargi,
+	cli_reader_opts_t* preader_opts, cli_writer_opts_t* pwriter_opts);
+
+void cli_opts_init(cli_opts_t* popts);
+void cli_reader_opts_init(cli_reader_opts_t* preader_opts);
+void cli_writer_opts_init(cli_writer_opts_t* pwriter_opts);
+
+void cli_apply_defaults(cli_opts_t* popts);
+void cli_apply_reader_defaults(cli_reader_opts_t* preader_opts);
+void cli_apply_writer_defaults(cli_writer_opts_t* pwriter_opts);
+
+// For mapper join which has its separate input-format overrides:
+void cli_merge_reader_opts(cli_reader_opts_t* pfunc_opts, cli_reader_opts_t* pmain_opts);
+
+// For mapper tee & mapper put which have their separate output-format overrides:
+void cli_merge_writer_opts(cli_writer_opts_t* pfunc_opts, cli_writer_opts_t* pmain_opts);
+
+void cli_opts_free(cli_opts_t* popts);
 
 // The caller can unconditionally free the return value
 char* cli_sep_from_arg(char* arg);
