@@ -142,20 +142,10 @@ static char* describe_state(int state);
 join_bucket_keeper_t* join_bucket_keeper_alloc(
 	char* prepipe,
 	char* left_file_name,
-	char* input_file_format,
-	int   use_mmap_for_read,
-	char* irs,
-	char* ifs,
-	int   allow_repeat_ifs,
-	char* ips,
-	int   allow_repeat_ips,
-	int   use_implicit_csv_header,
-	char* json_flatten_separator,
+	cli_reader_opts_t* popts,
 	slls_t* pleft_field_names
 ) {
-	lrec_reader_t* plrec_reader = lrec_reader_alloc(input_file_format, use_mmap_for_read,
-		irs, ifs, allow_repeat_ifs, ips, allow_repeat_ips, use_implicit_csv_header, json_flatten_separator);
-
+	lrec_reader_t* plrec_reader = lrec_reader_alloc(popts);
 	return join_bucket_keeper_alloc_from_reader(plrec_reader, prepipe, left_file_name, pleft_field_names);
 }
 
@@ -233,7 +223,7 @@ void join_bucket_keeper_emit(join_bucket_keeper_t* pkeeper, slls_t* pright_field
 			}
 		} else if (pkeeper->state != LEFT_STATE_3_EOF) {
 			fprintf(stderr, "%s: internal coding error: failed transition from prefill state.\n",
-				MLR_GLOBALS.argv0);
+				MLR_GLOBALS.bargv0);
 			exit(1);
 		}
 
@@ -294,7 +284,7 @@ static void join_bucket_keeper_fill(join_bucket_keeper_t* pkeeper, sllv_t** ppre
 		pkeeper->pleft_field_names);
 	if (pleft_field_values == NULL) {
 		fprintf(stderr, "%s: internal coding error: peek record should have had join keys.\n",
-			MLR_GLOBALS.argv0);
+			MLR_GLOBALS.bargv0);
 		exit(1);
 	}
 
@@ -497,7 +487,7 @@ void join_bucket_print(join_bucket_t* pbucket, char* indent) {
 		printf("%s  precords:\n", indent);
 		printf("%s    (null)\n", indent);
 	} else {
-		printf("%s  precords (length=%d):\n", indent, pbucket->precords->length);
+		printf("%s  precords (length=%llu):\n", indent, pbucket->precords->length);
 		lrec_print_list_with_prefix(pbucket->precords, "      ");
 	}
 	printf("%s  was_paired = %d\n", indent, pbucket->was_paired);
