@@ -14,7 +14,7 @@
 
 // ================================================================
 // MT for Miller type -- highly abbreviated here since these are
-// spelled out a lot in lrec_evaluators.c.
+// spelled out a lot in rval_evaluators.c.
 //
 // ================================================================
 // NOTE: mlrval functions invalidate their arguments. In particular, dynamically
@@ -60,54 +60,88 @@
 // There is also some use of mlrvals in mixed float/int handling inside various
 // mappers (e.g. stats1). There the use is much simpler: accumulation of
 // numeric quantities, ultimately formatted as a string for output.
+//
 // ================================================================
+//
+// Many functions here use the naming convention x_yz_name or x_:
+//
+// * The first letter indicates return type.
+//
+// * The letters between the underscores indicate argument types, and their count indicates arity.
+//
+// * The following abbreviations apply:
+//   o a: MT_ABSENT
+//   o v: MT_EMPTY (v for void; e is for error)
+//   o e: MT_ERROR
+//   o b: MT_BOOL
+//   o f: MT_FLOAT
+//   o i: MT_INT
+//   o s: MT_STRING
+//   o r: regular expression
+//   o n: Numeric, i.e. MT_INT or MT_FLOAT
+//   o x: any of the above.
+//   o z: used for zero-argument functions, e.g. f_z_urand takes no arguments and returns MT_FLOAT.
+//
+// * If a function takes arguments of type x then that indicates it has a disposition vector/matrix
+//   (or switch statements, or if-else statements) allowing it to handle various types.
+//
+// * If it takes arguments of type n then that indicates it is up to the caller to pass only numeric types.
+//
+// * If it takes arguments of type s then that indicates it is up to the caller to pass only strings.
+//
+// ================================================================
+
 
 // Among other things, these defines are used in mlrval.c to index disposition matrices.
 // So, if the numeric values are changed, all the matrices must be as well.
-#define MT_NULL   0 // E.g. field name not present in input record -- not a problem.
-#define MT_ERROR  1 // E.g. error encountered in one eval & it propagates up the AST.
-#define MT_BOOL   2
-#define MT_FLOAT  3
-#define MT_INT    4
-#define MT_STRING 5
-#define MT_MAX    6
+
+// Two kinds of null: absent (key not present in a record) and void (key present with empty value).
+// Note void is an acceptable string (empty string) but not an acceptable number.
+// Void-valued mlrvals have u.strv = "".
+#define MT_ERROR    0 // E.g. error encountered in one eval & it propagates up the AST.
+#define MT_ABSENT   1 // No such key, e.g. $z in 'x=,y=2'
+#define MT_EMPTY    2 // Empty value, e.g. $x in 'x=,y=2'
+#define MT_STRING   3
+#define MT_INT      4
+#define MT_FLOAT    5
+#define MT_BOOL     6
+#define MT_DIM      7
 
 #define MV_SB_ALLOC_LENGTH 32
 
 #define ISO8601_TIME_FORMAT "%Y-%m-%dT%H:%M:%SZ"
+#define ISO8601_DATE_FORMAT "%Y-%m-%d"
 
 typedef struct _mv_t {
 	union {
-		int        boolv;
-		double     fltv;
-		long long  intv;
-		char*      strv;
+		char*      strv;  // MT_STRING and MT_EMPTY
+		long long  intv;  // MT_INT, and == 0 for MT_ABSENT and MT_ERROR
+		double     fltv;  // MT_FLOAT
+		int        boolv; // MT_BOOL
 	} u;
 	unsigned char type;
-	unsigned char free_flags;
+	char free_flags;
 } mv_t;
 
 // ----------------------------------------------------------------
-extern mv_t MV_NULL;
-extern mv_t MV_ERROR;
-
-#define NULL_OR_ERROR_OUT(val) { \
-	if ((val).type == MT_ERROR) \
-		return MV_ERROR; \
-	if ((val).type == MT_NULL) \
-		return MV_NULL; \
+#define NULL_OR_ERROR_OUT_FOR_STRINGS(val) { \
+	if ((val).type < MT_EMPTY) \
+		return val; \
 }
 
-#define NULL_OUT(val) { \
-	if ((val).type == MT_NULL) \
-		return MV_NULL; \
+#define NULL_OR_ERROR_OUT_FOR_NUMBERS(val) { \
+	if ((val).type <= MT_EMPTY) \
+		return val; \
 }
-#define ERROR_OUT(val) { \
-	if ((val).type == MT_ERROR) \
-		return MV_ERROR; \
+
+#define EMPTY_OR_ERROR_OUT_FOR_NUMBERS(val) { \
+	if ((val).type == MT_ERROR || (val).type == MT_EMPTY) \
+		return val; \
 }
 
 // ----------------------------------------------------------------
+// CONSTRUCTORS
+
 static inline mv_t mv_from_float(double d) {
 	return (mv_t) {.type = MT_FLOAT, .free_flags = NO_FREE, .u.fltv = d};
 }
@@ -126,21 +160,20 @@ static inline mv_t mv_from_false() {
 	return (mv_t) {.type = MT_BOOL, .free_flags = NO_FREE, .u.boolv = FALSE};
 }
 
-static inline mv_t mv_from_null() {
-	return (mv_t) {.type = MT_NULL, .free_flags = NO_FREE, .u.intv = 0LL};
-}
-
 static inline mv_t mv_from_string_with_free(char* s) {
 	return (mv_t) {.type = MT_STRING, .free_flags = FREE_ENTRY_VALUE, .u.strv = s};
 }
 static inline mv_t mv_from_string_no_free(char* s) {
 	return (mv_t) {.type = MT_STRING, .free_flags = NO_FREE, .u.strv = s};
 }
-static inline mv_t mv_from_string(char* s, unsigned char free_flags) {
+static inline mv_t mv_from_string(char* s, char free_flags) {
 	return (mv_t) {.type = MT_STRING, .free_flags = free_flags, .u.strv = s};
 }
 
-// ----------------------------------------------------------------
+static inline mv_t mv_absent() { return (mv_t) {.type = MT_ABSENT, .free_flags = NO_FREE, .u.intv = 0};  }
+static inline mv_t mv_empty()  { return (mv_t) {.type = MT_EMPTY,  .free_flags = NO_FREE, .u.strv = ""}; }
+static inline mv_t mv_error()  { return (mv_t) {.type = MT_ERROR,  .free_flags = NO_FREE, .u.intv = 0};  }
+
 static inline mv_t mv_copy(mv_t* pval) {
 	if (pval->type == MT_STRING) {
 		return mv_from_string_with_free(mlr_strdup_or_die(pval->u.strv));
@@ -156,15 +189,8 @@ static inline mv_t* mv_alloc_copy(mv_t* pold) {
 }
 
 // ----------------------------------------------------------------
-static inline int mv_is_numeric(mv_t* pval) {
-	return pval->type == MT_INT || pval->type == MT_FLOAT;
-}
+// DESTRUCTOR
 
-static inline int mv_is_null(mv_t* pval) {
-	return pval->type == MT_NULL;
-}
-
-// ----------------------------------------------------------------
 static inline void mv_free(mv_t* pval) {
 	if ((pval->type) == MT_STRING && (pval->free_flags & FREE_ENTRY_VALUE)) {
 		free(pval->u.strv);
@@ -173,12 +199,63 @@ static inline void mv_free(mv_t* pval) {
 }
 
 // ----------------------------------------------------------------
-char* mt_describe_type(int type);
+// TYPE-TESTERS
+
+static inline int mv_is_string_or_empty(mv_t* pval) {
+	return pval->type == MT_STRING || pval->type == MT_EMPTY;
+}
+static inline int mv_is_numeric(mv_t* pval) {
+	return pval->type == MT_INT || pval->type == MT_FLOAT;
+}
+static inline int mv_is_null(mv_t* pval) {
+	return MT_ERROR < pval->type && pval->type <= MT_EMPTY;
+}
+static inline int mv_is_error(mv_t* pval) {
+	return pval->type == MT_ERROR;
+}
+static inline int mv_is_null_or_error(mv_t* pval) {
+	return pval->type <= MT_EMPTY;
+}
+static inline int mv_is_non_null(mv_t* pval) {
+	return MT_ERROR < pval->type && pval->type > MT_EMPTY;
+}
+static inline int mv_is_absent(mv_t* pval) {
+	return pval->type == MT_ABSENT;
+}
+static inline int mv_is_present(mv_t* pval) {
+	return pval->type != MT_ABSENT;
+}
+static inline int mv_is_empty(mv_t* pval) {
+	return pval->type == MT_EMPTY;
+}
+static inline int mv_is_not_empty(mv_t* pval) {
+	return pval->type != MT_EMPTY;
+}
+
+// ----------------------------------------------------------------
+// AUXILIARY METHODS
 
 char* mt_describe_type(int type);
+char* mt_describe_type_simple(int type);
+
+// Allocates memory which the caller must free; does not modify the mlrval.
+// Returns no reference to the mlrval's data.  Suitable for getting data out of
+// a mlrval which might be about to be freed.
 char* mv_alloc_format_val(mv_t* pval);
+
+// Returns a reference to the mlrval's data if the mlrval is MT_STRING.
+// Does not modify the mlrval. Suitable only for read-only string-formatting
+// of the mlrval while it still exists and hasn't been freed yet.
+char* mv_maybe_alloc_format_val(mv_t* pval, char* pfree_flags);
+
+// If the mlrval is MT_STRING, returns that and invalidates the argument.
+// This is suitable for baton-pass-out (end of evaluation chain).
 char* mv_format_val(mv_t* pval, char* pfree_flags);
+
+// Output string includes type and value information (e.g. for debug).
+// The caller must free the return value.
 char* mv_describe_val(mv_t val);
+
 void mv_set_boolean_strict(mv_t* pval);
 void mv_set_float_strict(mv_t* pval);
 void mv_set_float_nullable(mv_t* pval);
@@ -190,6 +267,8 @@ mv_t mv_scan_number_nullable(char* string);
 mv_t mv_scan_number_or_die(char* string);
 
 // ----------------------------------------------------------------
+// FUNCTION-OF-MLRVAL TYPES
+
 typedef mv_t mv_zary_func_t();
 typedef mv_t mv_unary_func_t(mv_t* pval1);
 typedef mv_t mv_binary_func_t(mv_t* pval1, mv_t* pval2);
@@ -199,6 +278,8 @@ typedef mv_t mv_ternary_func_t(mv_t* pval1, mv_t* pval2, mv_t* pval3);
 typedef mv_t mv_ternary_arg2_regex_func_t(mv_t* pval1, regex_t* pregex, string_builder_t* psb, mv_t* pval3);
 
 // ----------------------------------------------------------------
+// FUNCTIONS OF MLRVALS
+
 static inline mv_t b_b_not_func(mv_t* pval1) {
 	return mv_from_bool(!pval1->u.boolv);
 }
@@ -253,27 +334,43 @@ static inline mv_t f_ff_pow_func(mv_t* pval1, mv_t* pval2) {
 	return mv_from_float(pow(pval1->u.fltv, pval2->u.fltv));
 }
 
-mv_t n_nn_plus_func(mv_t* pval1, mv_t* pval2);
-mv_t n_nn_minus_func(mv_t* pval1, mv_t* pval2);
-mv_t n_nn_times_func(mv_t* pval1, mv_t* pval2);
-mv_t n_nn_divide_func(mv_t* pval1, mv_t* pval2);
-mv_t n_nn_int_divide_func(mv_t* pval1, mv_t* pval2);
-mv_t n_nn_mod_func(mv_t* pval1, mv_t* pval2);
-mv_t n_n_upos_func(mv_t* pval1);
-mv_t n_n_uneg_func(mv_t* pval1);
+mv_t x_xx_plus_func(mv_t* pval1, mv_t* pval2);
+mv_t x_xx_minus_func(mv_t* pval1, mv_t* pval2);
+mv_t x_xx_times_func(mv_t* pval1, mv_t* pval2);
+mv_t x_xx_divide_func(mv_t* pval1, mv_t* pval2);
+mv_t x_xx_int_divide_func(mv_t* pval1, mv_t* pval2);
+mv_t x_xx_mod_func(mv_t* pval1, mv_t* pval2);
+mv_t x_x_upos_func(mv_t* pval1);
+mv_t x_x_uneg_func(mv_t* pval1);
 
-mv_t n_n_abs_func(mv_t* pval1);
-mv_t n_n_ceil_func(mv_t* pval1);
-mv_t n_n_floor_func(mv_t* pval1);
-mv_t n_n_round_func(mv_t* pval1);
-mv_t n_n_sgn_func(mv_t* pval1);
+// Bitwise
+mv_t x_xx_bxor_func(mv_t* pval1, mv_t* pval2);
+mv_t x_xx_band_func(mv_t* pval1, mv_t* pval2);
+mv_t x_xx_bor_func(mv_t* pval1, mv_t* pval2);
 
-mv_t n_nn_min_func(mv_t* pval1, mv_t* pval2);
-mv_t n_nn_max_func(mv_t* pval1, mv_t* pval2);
-mv_t n_nn_roundm_func(mv_t* pval1, mv_t* pval2);
+mv_t x_x_abs_func(mv_t* pval1);
+mv_t x_x_ceil_func(mv_t* pval1);
+mv_t x_x_floor_func(mv_t* pval1);
+mv_t x_x_round_func(mv_t* pval1);
+mv_t x_x_sgn_func(mv_t* pval1);
+
+mv_t x_xx_min_func(mv_t* pval1, mv_t* pval2);
+mv_t x_xx_max_func(mv_t* pval1, mv_t* pval2);
+mv_t x_xx_roundm_func(mv_t* pval1, mv_t* pval2);
 
 mv_t b_x_isnull_func(mv_t* pval1);
 mv_t b_x_isnotnull_func(mv_t* pval1);
+mv_t b_x_isabsent_func(mv_t* pval1);
+mv_t b_x_ispresent_func(mv_t* pval1);
+mv_t b_x_isempty_func(mv_t* pval1);
+mv_t b_x_isnotempty_func(mv_t* pval1);
+
+mv_t b_x_isnumeric_func(mv_t* pval1);
+mv_t b_x_isint_func(mv_t* pval1);
+mv_t b_x_isfloat_func(mv_t* pval1);
+mv_t b_x_isbool_func(mv_t* pval1);
+mv_t b_x_isstring_func(mv_t* pval1);
+
 mv_t i_x_int_func(mv_t* pval1);
 mv_t f_x_float_func(mv_t* pval1);
 mv_t b_x_boolean_func(mv_t* pval1);
@@ -308,15 +405,6 @@ static inline mv_t i_ii_urandint_func(mv_t* pval1, mv_t* pval2) {
 	return mv_from_int(u);
 }
 
-static inline mv_t i_ii_bitwise_or_func(mv_t* pval1, mv_t* pval2) {
-	return mv_from_int(pval1->u.intv | pval2->u.intv);
-}
-static inline mv_t i_ii_bitwise_xor_func(mv_t* pval1, mv_t* pval2) {
-	return mv_from_int(pval1->u.intv ^ pval2->u.intv);
-}
-static inline mv_t i_ii_bitwise_and_func(mv_t* pval1, mv_t* pval2) {
-	return mv_from_int(pval1->u.intv & pval2->u.intv);
-}
 static inline mv_t i_ii_bitwise_lsh_func(mv_t* pval1, mv_t* pval2) {
 	return mv_from_int(pval1->u.intv << pval2->u.intv);
 }
@@ -335,8 +423,10 @@ mv_t i_iii_modexp_func(mv_t* pval1, mv_t* pval2, mv_t* pval3);
 // ----------------------------------------------------------------
 mv_t s_s_tolower_func(mv_t* pval1);
 mv_t s_s_toupper_func(mv_t* pval1);
+mv_t i_s_strlen_func(mv_t* pval1);
+mv_t s_x_typeof_func(mv_t* pval1);
 
-mv_t s_ss_dot_func(mv_t* pval1, mv_t* pval2);
+mv_t s_xx_dot_func(mv_t* pval1, mv_t* pval2);
 
 mv_t sub_no_precomp_func(mv_t* pval1, mv_t* pval2, mv_t* pval3);
 mv_t sub_precomp_func(mv_t* pval1, regex_t* pregex, string_builder_t* psb, mv_t* pval3);
@@ -344,7 +434,8 @@ mv_t gsub_no_precomp_func(mv_t* pval1, mv_t* pval2, mv_t* pval3);
 mv_t gsub_precomp_func(mv_t* pval1, regex_t* pregex, string_builder_t* psb, mv_t* pval3);
 
 // ----------------------------------------------------------------
-mv_t s_n_sec2gmt_func(mv_t* pval1);
+mv_t s_x_sec2gmt_func(mv_t* pval1);
+mv_t s_x_sec2gmtdate_func(mv_t* pval1);
 mv_t i_s_gmt2sec_func(mv_t* pval1);
 mv_t s_ns_strftime_func(mv_t* pval1, mv_t* pval2);
 mv_t i_ss_strptime_func(mv_t* pval1, mv_t* pval2);
@@ -360,8 +451,6 @@ mv_t f_s_dhms2fsec_func(mv_t* pval1);
 
 mv_t time_string_from_seconds(mv_t* psec, char* format);
 
-mv_t i_s_strlen_func(mv_t* pval1);
-
 // ----------------------------------------------------------------
 // arg2 evaluates to string via compound expression; regexes compiled on each call
 mv_t matches_no_precomp_func(mv_t* pval1, mv_t* pval2, string_array_t** ppregex_captures);
@@ -389,6 +478,9 @@ int mv_i_nn_ge(mv_t* pval1, mv_t* pval2);
 int mv_i_nn_lt(mv_t* pval1, mv_t* pval2);
 int mv_i_nn_le(mv_t* pval1, mv_t* pval2);
 
+// For unit-test keystroke-saving:
+int mveq(mv_t* pval1, mv_t* pval2);
+
 // ----------------------------------------------------------------
 // For qsort of numeric mlrvals.
 int mv_nn_comparator(const void* pva, const void* pvb);
