@@ -16,7 +16,10 @@ typedef struct _percentile_keeper_t {
 percentile_keeper_t* percentile_keeper_alloc();
 void percentile_keeper_free(percentile_keeper_t* ppercentile_keeper);
 void percentile_keeper_ingest(percentile_keeper_t* ppercentile_keeper, mv_t value);
-mv_t percentile_keeper_emit(percentile_keeper_t* ppercentile_keeper, double percentile);
+
+typedef mv_t percentile_keeper_emitter_t(percentile_keeper_t* ppercentile_keeper, double percentile);
+mv_t percentile_keeper_emit_non_interpolated(percentile_keeper_t* ppercentile_keeper, double percentile);
+mv_t percentile_keeper_emit_linearly_interpolated(percentile_keeper_t* ppercentile_keeper, double percentile);
 
 // For debug/test
 void percentile_keeper_print(percentile_keeper_t* ppercentile_keeper);
