@@ -2,6 +2,6 @@
 #define MLR_DSL_WRAPPER_H
 #include  "../containers/mlr_dsl_ast.h"
 
-mlr_dsl_ast_t* mlr_dsl_parse(char* string);
+mlr_dsl_ast_t* mlr_dsl_parse(char* string, int trace_parse);
 
 #endif // MLR_DSL_WRAPPER_H
