@@ -26,6 +26,11 @@
 // SUCH DAMAGE.
 // ================================================================
 
+// Miller to-do items:
+// 1. Modify the data structures so sval & length are shared between boolean, integer, & double.
+// 2. Just append a byte-range (start to end pointer) rather than making repeated per-character calls
+//    to these functions.
+
 #include "lib/mlrutil.h"
 #include "json_parser.h"
 
@@ -198,11 +203,6 @@ static int new_value(
 #define STRING_ADD(b)  \
 	do { if (!state.first_pass) string[string_length] = b;  ++string_length; } while (0);
 
-
-// xxx to do:
-// 1. Modify the data structure so sval & length are shared between boolean, integer, & double.
-// 2. Just append a byte-range (start to end pointer) rather than making repeated per-character calls
-//    to these functions.
 static inline void boolean_sval_add(json_parser_state_t* pstate, json_value_t* ptop, char b) {
 	if (!pstate->first_pass) {
 		ptop->u.boolean.sval[ptop->u.boolean.length++] = b;
@@ -862,7 +862,7 @@ e_failed:
 	}
 
 	if (!state.first_pass)
-		json_value_free(proot);
+		json_free_value(proot);
 
 	return 0;
 }
@@ -876,7 +876,7 @@ json_value_t * json_parse_for_unit_test(
 }
 
 // ----------------------------------------------------------------
-void json_value_free(json_value_t * pvalue) {
+void json_free_value(json_value_t * pvalue) {
 	json_value_t * cur_value;
 
 	if (!pvalue)
@@ -887,12 +887,10 @@ void json_value_free(json_value_t * pvalue) {
 	while (pvalue) {
 		switch (pvalue->type) {
 			case JSON_ARRAY:
-
 				if (!pvalue->u.array.length) {
 					free(pvalue->u.array.values);
 					break;
 				}
-
 				pvalue = pvalue->u.array.values[--pvalue->u.array.length];
 				continue;
 
@@ -901,7 +899,6 @@ void json_value_free(json_value_t * pvalue) {
 					free(pvalue->u.object.p.values);
 					break;
 				}
-
 				pvalue = pvalue->u.object.p.values[--pvalue->u.object.length].pvalue;
 				continue;
 
@@ -961,31 +958,31 @@ static void json_print_non_recursive_aux(json_value_t* pvalue, int depth) {
 	}
 	printf("type=%s", json_describe_type(pvalue->type));
 	switch(pvalue->type) {
-    case JSON_NONE:
+	case JSON_NONE:
 		break;
-    case JSON_OBJECT:
+	case JSON_OBJECT:
 		printf(",length=%d", pvalue->u.object.length);
 		break;
-    case JSON_ARRAY:
+	case JSON_ARRAY:
 		printf(",length=%d", pvalue->u.object.length);
 		break;
-    case JSON_INTEGER:
+	case JSON_INTEGER:
 		printf(",length=%d", pvalue->u.integer.length);
 		printf(",sval=\"%s\"", pvalue->u.integer.sval);
 		break;
-    case JSON_DOUBLE:
+	case JSON_DOUBLE:
 		printf(",length=%d", pvalue->u.dbl.length);
 		printf(",sval=\"%s\"", pvalue->u.dbl.sval);
 		break;
-    case JSON_STRING:
+	case JSON_STRING:
 		printf(",length=%d", pvalue->u.string.length);
 		printf(",ptr=\"%s\"", pvalue->u.string.ptr);
 		break;
-    case JSON_BOOLEAN:
+	case JSON_BOOLEAN:
 		printf(",length=%d", pvalue->u.boolean.length);
 		printf(",sval=\"%s\"", pvalue->u.boolean.sval);
 		break;
-    case JSON_NULL:
+	case JSON_NULL:
 		break;
 	}
 	printf("\n");
