@@ -131,7 +131,7 @@ static lrec_t* lrec_reader_mmap_csvlite_process_single_seps(void* pvstate, void*
 			for (sllse_t* pe = pheader_fields->phead; pe != NULL; pe = pe->pnext) {
 				if (*pe->value == 0) {
 					fprintf(stderr, "%s: unacceptable empty CSV key at file \"%s\" line %lld.\n",
-						MLR_GLOBALS.argv0, pctx->filename, pstate->ilno);
+						MLR_GLOBALS.bargv0, pctx->filename, pstate->ilno);
 					exit(1);
 				}
 			}
@@ -177,7 +177,7 @@ static lrec_t* lrec_reader_mmap_csvlite_process_multi_seps(void* pvstate, void*
 			for (sllse_t* pe = pheader_fields->phead; pe != NULL; pe = pe->pnext) {
 				if (*pe->value == 0) {
 					fprintf(stderr, "%s: unacceptable empty CSV key at file \"%s\" line %lld.\n",
-						MLR_GLOBALS.argv0, pctx->filename, pstate->ilno);
+						MLR_GLOBALS.bargv0, pctx->filename, pstate->ilno);
 					exit(1);
 				}
 			}
@@ -360,7 +360,7 @@ static lrec_t* lrec_reader_mmap_csvlite_get_record_single_seps(file_reader_mmap_
 			*p = 0;
 			if (pe == NULL) {
 				fprintf(stderr, "%s: Header-data length mismatch in file %s at line %lld.\n",
-					MLR_GLOBALS.argv0, pctx->filename, pstate->ilno);
+					MLR_GLOBALS.bargv0, pctx->filename, pstate->ilno);
 				exit(1);
 			}
 			key = pe->value;
@@ -385,14 +385,14 @@ static lrec_t* lrec_reader_mmap_csvlite_get_record_single_seps(file_reader_mmap_
 
 	if (pe == NULL) {
 		fprintf(stderr, "%s: Header-data length mismatch in file %s at line %lld.\n",
-			MLR_GLOBALS.argv0, pctx->filename, pstate->ilno);
+			MLR_GLOBALS.bargv0, pctx->filename, pstate->ilno);
 		exit(1);
 	}
 	key = pe->value;
 
 	if (saw_rs) {
-        // Easy and simple case: we read until end of line.  We zero-poked the irs to a null character to terminate the
-        // C string so it's OK to retain a pointer to that.
+		// Easy and simple case: we read until end of line.  We zero-poked the irs to a null character to terminate the
+		// C string so it's OK to retain a pointer to that.
 		lrec_put(prec, key, value, NO_FREE);
 	} else {
 		// Messier case: we read to end of file without seeing end of line.  We can't always zero-poke a null character
@@ -405,7 +405,7 @@ static lrec_t* lrec_reader_mmap_csvlite_get_record_single_seps(file_reader_mmap_
 
 	if (pe->pnext != NULL) {
 		fprintf(stderr, "%s: Header-data length mismatch in file %s at line %lld.\n",
-			MLR_GLOBALS.argv0, pctx->filename, pstate->ilno);
+			MLR_GLOBALS.bargv0, pctx->filename, pstate->ilno);
 		exit(1);
 	}
 
@@ -453,7 +453,7 @@ static lrec_t* lrec_reader_mmap_csvlite_get_record_multi_seps(file_reader_mmap_s
 			*p = 0;
 			if (pe == NULL) {
 				fprintf(stderr, "%s: Header-data length mismatch in file %s at line %lld.\n",
-					MLR_GLOBALS.argv0, pctx->filename, pstate->ilno);
+					MLR_GLOBALS.bargv0, pctx->filename, pstate->ilno);
 				exit(1);
 			}
 			key = pe->value;
@@ -478,14 +478,14 @@ static lrec_t* lrec_reader_mmap_csvlite_get_record_multi_seps(file_reader_mmap_s
 
 	if (pe == NULL) {
 		fprintf(stderr, "%s: Header-data length mismatch in file %s at line %lld.\n",
-			MLR_GLOBALS.argv0, pctx->filename, pstate->ilno);
+			MLR_GLOBALS.bargv0, pctx->filename, pstate->ilno);
 		exit(1);
 	}
 	key = pe->value;
 
 	if (saw_rs) {
-        // Easy and simple case: we read until end of line.  We zero-poked the irs to a null character to terminate the
-        // C string so it's OK to retain a pointer to that.
+		// Easy and simple case: we read until end of line.  We zero-poked the irs to a null character to terminate the
+		// C string so it's OK to retain a pointer to that.
 		lrec_put(prec, key, value, NO_FREE);
 	} else {
 		// Messier case: we read to end of file without seeing end of line.  We can't always zero-poke a null character
@@ -498,7 +498,7 @@ static lrec_t* lrec_reader_mmap_csvlite_get_record_multi_seps(file_reader_mmap_s
 
 	if (pe->pnext != NULL) {
 		fprintf(stderr, "%s: Header-data length mismatch in file %s at line %lld.\n",
-			MLR_GLOBALS.argv0, pctx->filename, pstate->ilno);
+			MLR_GLOBALS.bargv0, pctx->filename, pstate->ilno);
 		exit(1);
 	}
 
@@ -527,7 +527,7 @@ static lrec_t* lrec_reader_mmap_csvlite_get_record_single_seps_implicit_header(f
 	}
 	char* key   = NULL;
 	char* value = p;
-	char  free_flags;
+	char  free_flags = NO_FREE;
 	int idx = 0;
 	int saw_rs = FALSE;
 	for ( ; p < phandle->eof && *p; ) {
@@ -565,8 +565,8 @@ static lrec_t* lrec_reader_mmap_csvlite_get_record_single_seps_implicit_header(f
 	key = make_nidx_key(++idx, &free_flags);
 
 	if (saw_rs) {
-        // Easy and simple case: we read until end of line.  We zero-poked the irs to a null character to terminate the
-        // C string so it's OK to retain a pointer to that.
+		// Easy and simple case: we read until end of line.  We zero-poked the irs to a null character to terminate the
+		// C string so it's OK to retain a pointer to that.
 		lrec_put(prec, key, value, free_flags);
 	} else {
 		// Messier case: we read to end of file without seeing end of line.  We can't always zero-poke a null character
@@ -603,7 +603,7 @@ static lrec_t* lrec_reader_mmap_csvlite_get_record_multi_seps_implicit_header(fi
 	}
 	char* key   = NULL;
 	char* value = p;
-	char  free_flags;
+	char free_flags;
 	int idx = 0;
 	int saw_rs = FALSE;
 	for ( ; p < phandle->eof && *p; ) {
@@ -642,8 +642,8 @@ static lrec_t* lrec_reader_mmap_csvlite_get_record_multi_seps_implicit_header(fi
 	key = make_nidx_key(++idx, &free_flags);
 
 	if (saw_rs) {
-        // Easy and simple case: we read until end of line.  We zero-poked the irs to a null character to terminate the
-        // C string so it's OK to retain a pointer to that.
+		// Easy and simple case: we read until end of line.  We zero-poked the irs to a null character to terminate the
+		// C string so it's OK to retain a pointer to that.
 		lrec_put(prec, key, value, free_flags);
 	} else {
 		// Messier case: we read to end of file without seeing end of line.  We can't always zero-poke a null character
