@@ -3,6 +3,7 @@
 
 #include <stdio.h>
 #include "lib/context.h"
+#include "cli/mlrcli.h"
 #include "containers/lrec.h"
 #include "containers/sllv.h"
 
@@ -28,7 +29,8 @@ typedef struct _mapper_t {
 // Control plane:
 
 typedef void mapper_usage_func_t(FILE* o, char* argv0, char* verb);
-typedef      mapper_t* mapper_parse_cli_func_t(int* pargi, int argc, char** argv);
+typedef      mapper_t* mapper_parse_cli_func_t(int* pargi, int argc, char** argv,
+	cli_reader_opts_t* pmain_reader_opts, cli_writer_opts_t* pmain_writer_opts);
 
 typedef struct _mapper_setup_t {
 	char*                    verb;
