@@ -13,7 +13,8 @@ typedef struct _mapper_bootstrap_state_t {
 } mapper_bootstrap_state_t;
 
 static void      mapper_bootstrap_usage(FILE* o, char* argv0, char* verb);
-static mapper_t* mapper_bootstrap_parse_cli(int* pargi, int argc, char** argv);
+static mapper_t* mapper_bootstrap_parse_cli(int* pargi, int argc, char** argv,
+	cli_reader_opts_t* _, cli_writer_opts_t* __);
 static mapper_t* mapper_bootstrap_alloc(int nout, ap_state_t* pargp);
 static void      mapper_bootstrap_free(mapper_t* pmapper);
 static sllv_t*   mapper_bootstrap_process(lrec_t* pinrec, context_t* pctx, void* pvstate);
@@ -35,7 +36,9 @@ static void mapper_bootstrap_usage(FILE* o, char* argv0, char* verb) {
 	fprintf(o, "See also %s sample and %s shuffle.\n", argv0, argv0);
 }
 
-static mapper_t* mapper_bootstrap_parse_cli(int* pargi, int argc, char** argv) {
+static mapper_t* mapper_bootstrap_parse_cli(int* pargi, int argc, char** argv,
+	cli_reader_opts_t* _, cli_writer_opts_t* __)
+{
 	int nout = NOUT_EQUALS_NIN;
 	if ((argc - *pargi) < 1) {
 		mapper_bootstrap_usage(stderr, argv[0], argv[*pargi]);
