@@ -12,7 +12,8 @@ typedef struct _mapper_cat_state_t {
 #define DEFAULT_COUNTER_FIELD_NAME "n"
 
 static void      mapper_cat_usage(FILE* o, char* argv0, char* verb);
-static mapper_t* mapper_cat_parse_cli(int* pargi, int argc, char** argv);
+static mapper_t* mapper_cat_parse_cli(int* pargi, int argc, char** argv,
+	cli_reader_opts_t* _, cli_writer_opts_t* __);
 static mapper_t* mapper_cat_alloc(ap_state_t* pargp, int do_counters, char* counter_field_name);
 static void      mapper_cat_free(mapper_t* pmapper);
 static sllv_t*   mapper_cat_process(lrec_t* pinrec, context_t* pctx, void* pvstate);
@@ -26,7 +27,9 @@ mapper_setup_t mapper_cat_setup = {
 };
 
 // ----------------------------------------------------------------
-static mapper_t* mapper_cat_parse_cli(int* pargi, int argc, char** argv) {
+static mapper_t* mapper_cat_parse_cli(int* pargi, int argc, char** argv,
+	cli_reader_opts_t* _, cli_writer_opts_t* __)
+{
 	char* default_counter_field_name = DEFAULT_COUNTER_FIELD_NAME;
 	char* counter_field_name = NULL;
 	int   do_counters = FALSE;
