@@ -7,18 +7,17 @@
 #include "containers/join_bucket_keeper.h"
 #include "mapping/mappers.h"
 #include "input/lrec_readers.h"
-#include "cli/argparse.h"
 
 // ----------------------------------------------------------------
-// Join options, if unspecified, default to respective main options.
-#define OPTION_UNSPECIFIED ((char)0xff)
-
 typedef struct _mapper_join_opts_t {
 	char*    left_prefix;
 	char*    right_prefix;
+	slls_t*  poutput_join_field_names;
 	slls_t*  pleft_join_field_names;
 	slls_t*  pright_join_field_names;
-	slls_t*  poutput_join_field_names;
+	char*    output_join_field_names_cli_backing;
+	char*    left_join_field_names_cli_backing;
+	char*    right_join_field_names_cli_backing;
 	int      allow_unsorted_input;
 	int      emit_pairables;
 	int      emit_left_unpairables;
@@ -33,7 +32,6 @@ typedef struct _mapper_join_opts_t {
 } mapper_join_opts_t;
 
 typedef struct _mapper_join_state_t {
-	ap_state_t* pargp;
 
 	mapper_join_opts_t* popts;
 
@@ -51,10 +49,10 @@ typedef struct _mapper_join_state_t {
 
 // ----------------------------------------------------------------
 static void mapper_join_usage(FILE* o, char* argv0, char* verb);
-static mapper_t* mapper_join_parse_cli(int* pargi, int argc, char** argv);
-static mapper_t* mapper_join_alloc(ap_state_t* pargp, mapper_join_opts_t* popts);
+static mapper_t* mapper_join_parse_cli(int* pargi, int argc, char** argv,
+	cli_reader_opts_t* _, cli_writer_opts_t* __);
+static mapper_t* mapper_join_alloc(mapper_join_opts_t* popts);
 static void mapper_join_free(mapper_t* pmapper);
-static void merge_options(cli_reader_opts_t* popts);
 static void ingest_left_file(mapper_join_state_t* pstate);
 static void mapper_join_form_pairs(sllv_t* pleft_records, lrec_t* pright_rec, mapper_join_state_t* pstate,
 	sllv_t* pout_recs);
@@ -114,61 +112,123 @@ static void mapper_join_usage(FILE* o, char* argv0, char* verb) {
 }
 
 // ----------------------------------------------------------------
-static mapper_t* mapper_join_parse_cli(int* pargi, int argc, char** argv) {
+static mapper_t* mapper_join_parse_cli(int* pargi, int argc, char** argv,
+	cli_reader_opts_t* pmain_reader_opts, cli_writer_opts_t* __)
+{
 	mapper_join_opts_t* popts = mlr_malloc_or_die(sizeof(mapper_join_opts_t));
-	popts->left_prefix              = NULL;
-	popts->right_prefix             = NULL;
-	popts->prepipe                  = NULL;
-	popts->left_file_name           = NULL;
-	popts->poutput_join_field_names = NULL;
-	popts->pleft_join_field_names   = NULL;
-	popts->pright_join_field_names  = NULL;
-	popts->allow_unsorted_input     = FALSE;
-	popts->emit_pairables           = TRUE;
-	popts->emit_left_unpairables    = FALSE;
-	popts->emit_right_unpairables   = FALSE;
 
-	popts->reader_opts.ifile_fmt         = NULL;
-	popts->reader_opts.irs               = NULL;
-	popts->reader_opts.ifs               = NULL;
-	popts->reader_opts.ips               = NULL;
-	popts->reader_opts.allow_repeat_ifs  = OPTION_UNSPECIFIED;
-	popts->reader_opts.allow_repeat_ips  = OPTION_UNSPECIFIED;
-	popts->reader_opts.use_implicit_csv_header = OPTION_UNSPECIFIED;
-	popts->reader_opts.use_mmap_for_read = OPTION_UNSPECIFIED;
-	popts->reader_opts.input_json_flatten_separator = NULL;
+	cli_reader_opts_init(&popts->reader_opts);
 
-	char* verb = argv[(*pargi)++];
+	popts->left_prefix                         = NULL;
+	popts->right_prefix                        = NULL;
+	popts->prepipe                             = NULL;
+	popts->left_file_name                      = NULL;
+	popts->poutput_join_field_names            = NULL;
+	popts->pleft_join_field_names              = NULL;
+	popts->pright_join_field_names             = NULL;
+	popts->output_join_field_names_cli_backing = NULL;
+	popts->left_join_field_names_cli_backing   = NULL;
+	popts->right_join_field_names_cli_backing  = NULL;
+	popts->emit_pairables                      = TRUE;
+	popts->emit_left_unpairables               = FALSE;
+	popts->emit_right_unpairables              = FALSE;
+	popts->allow_unsorted_input                = FALSE;
 
-	ap_state_t* pstate = ap_alloc();
-	ap_define_string_flag(pstate,      "--prepipe",  &popts->prepipe);
-	ap_define_string_flag(pstate,      "-f",         &popts->left_file_name);
-	ap_define_string_list_flag(pstate, "-j",         &popts->poutput_join_field_names);
-	ap_define_string_list_flag(pstate, "-l",         &popts->pleft_join_field_names);
-	ap_define_string_list_flag(pstate, "-r",         &popts->pright_join_field_names);
-	ap_define_string_flag(pstate,      "--lp",       &popts->left_prefix);
-	ap_define_string_flag(pstate,      "--rp",       &popts->right_prefix);
-	ap_define_false_flag(pstate,       "--np",       &popts->emit_pairables);
-	ap_define_true_flag(pstate,        "--ul",       &popts->emit_left_unpairables);
-	ap_define_true_flag(pstate,        "--ur",       &popts->emit_right_unpairables);
-	ap_define_true_flag(pstate,        "-u",         &popts->allow_unsorted_input);
+	int argi = *pargi;
+	char* verb = argv[argi++];
 
-	ap_define_string_flag(pstate,      "-i",         &popts->reader_opts.ifile_fmt);
-	ap_define_string_flag(pstate,      "--irs",      &popts->reader_opts.irs);
-	ap_define_string_flag(pstate,      "--ifs",      &popts->reader_opts.ifs);
-	ap_define_string_flag(pstate,      "--ips",      &popts->reader_opts.ips);
-	ap_define_true_flag(pstate,        "--repifs",   &popts->reader_opts.allow_repeat_ifs);
-	ap_define_true_flag(pstate,        "--repips",   &popts->reader_opts.allow_repeat_ips);
-	ap_define_true_flag(pstate,        "--implicit-csv-header", &popts->reader_opts.use_implicit_csv_header);
-	ap_define_true_flag(pstate,        "--use-mmap", &popts->reader_opts.use_mmap_for_read);
-	ap_define_false_flag(pstate,       "--no-mmap",  &popts->reader_opts.use_mmap_for_read);
-	ap_define_string_flag(pstate,      "--jflatsep", &popts->reader_opts.input_json_flatten_separator);
+	for (; argi < argc; /* variable increment: 1 or 2 depending on flag */) {
+
+		if (argv[argi][0] != '-') {
+			break; // No more flag options to process
+
+		} else if (cli_handle_reader_options(argv, argc, &argi, &popts->reader_opts)) {
+			// handled
+
+		} else if (streq(argv[argi], "--prepipe")) {
+			if ((argc - argi) < 2) {
+				mapper_join_usage(stderr, argv[0], verb);
+				return NULL;
+			}
+			popts->prepipe = argv[argi+1];
+			argi += 2;
+
+		} else if (streq(argv[argi], "-f")) {
+			if ((argc - argi) < 2) {
+				mapper_join_usage(stderr, argv[0], verb);
+				return NULL;
+			}
+			popts->left_file_name = argv[argi+1];
+			argi += 2;
+
+		} else if (streq(argv[argi], "-j")) {
+			if ((argc - argi) < 2) {
+				mapper_join_usage(stderr, argv[0], verb);
+				return NULL;
+			}
+			popts->output_join_field_names_cli_backing = mlr_strdup_or_die(argv[argi+1]);
+			popts->poutput_join_field_names = slls_from_line(popts->output_join_field_names_cli_backing, ',', FALSE);
+			argi += 2;
+
+		} else if (streq(argv[argi], "-l")) {
+			if ((argc - argi) < 2) {
+				mapper_join_usage(stderr, argv[0], verb);
+				return NULL;
+			}
+			popts->left_join_field_names_cli_backing   = mlr_strdup_or_die(argv[argi+1]);
+			popts->pleft_join_field_names = slls_from_line(popts->left_join_field_names_cli_backing, ',', FALSE);
+			argi += 2;
+
+		} else if (streq(argv[argi], "-r")) {
+			if ((argc - argi) < 2) {
+				mapper_join_usage(stderr, argv[0], verb);
+				return NULL;
+			}
+			popts->right_join_field_names_cli_backing  = mlr_strdup_or_die(argv[argi+1]);
+			popts->pright_join_field_names = slls_from_line(popts->right_join_field_names_cli_backing, ',', FALSE);
+			argi += 2;
+
+		} else if (streq(argv[argi], "--lp")) {
+			if ((argc - argi) < 2) {
+				mapper_join_usage(stderr, argv[0], verb);
+				return NULL;
+			}
+			popts->left_prefix = argv[argi+1];
+			argi += 2;
+
+		} else if (streq(argv[argi], "--rp")) {
+			if ((argc - argi) < 2) {
+				mapper_join_usage(stderr, argv[0], verb);
+				return NULL;
+			}
+			popts->right_prefix = argv[argi+1];
+			argi += 2;
+
+		} else if (streq(argv[argi], "--np")) {
+			popts->emit_pairables = FALSE;
+			argi += 1;
+
+		} else if (streq(argv[argi], "--ul")) {
+			popts->emit_left_unpairables = TRUE;
+			argi += 1;
+
+		} else if (streq(argv[argi], "--ur")) {
+			popts->emit_right_unpairables = TRUE;
+			argi += 1;
+
+		} else if (streq(argv[argi], "-u")) {
+			popts->allow_unsorted_input = TRUE;
+			argi += 1;
+
+		} else {
+			mapper_join_usage(stderr, argv[0], verb);
+			return NULL;
+		}
 
-	if (!ap_parse(pstate, verb, pargi, argc, argv)) {
-		mapper_join_usage(stderr, argv[0], verb);
-		return NULL;
 	}
 
+	cli_merge_reader_opts(&popts->reader_opts, pmain_reader_opts);
+
 	// popen is a stdio construct, not an mmap construct, and it can't be supported here.
 	if (popts->prepipe != NULL)
 		popts->reader_opts.use_mmap_for_read = FALSE;
@@ -206,20 +266,26 @@ static mapper_t* mapper_join_parse_cli(int* pargi, int argc, char** argv) {
 		exit(1);
 	}
 
-	return mapper_join_alloc(pstate, popts);
+	*pargi = argi;
+
+	return mapper_join_alloc(popts);
 }
 
 // ----------------------------------------------------------------
-static mapper_t* mapper_join_alloc(ap_state_t* pargp, mapper_join_opts_t* popts)
-{
+static mapper_t* mapper_join_alloc(mapper_join_opts_t* popts) {
 	mapper_t* pmapper = mlr_malloc_or_die(sizeof(mapper_t));
 
 	mapper_join_state_t* pstate = mlr_malloc_or_die(sizeof(mapper_join_state_t));
-	pstate->pargp                              = pargp;
 	pstate->popts                              = popts;
 	pstate->pleft_field_name_set               = hss_from_slls(popts->pleft_join_field_names);
 	pstate->pright_field_name_set              = hss_from_slls(popts->pright_join_field_names);
-	pstate->pjoin_bucket_keeper                = NULL;
+
+	pstate->pjoin_bucket_keeper = join_bucket_keeper_alloc(
+		popts->prepipe,
+		popts->left_file_name,
+		&popts->reader_opts,
+		popts->pleft_join_field_names);
+
 	pstate->pleft_buckets_by_join_field_values = NULL;
 	pstate->pleft_unpaired_records             = NULL;
 
@@ -237,11 +303,6 @@ static mapper_t* mapper_join_alloc(ap_state_t* pargp, mapper_join_opts_t* popts)
 // ----------------------------------------------------------------
 static void mapper_join_free(mapper_t* pmapper) {
 	mapper_join_state_t* pstate = pmapper->pvstate;
-	slls_free(pstate->popts->pleft_join_field_names);
-	slls_free(pstate->popts->pright_join_field_names);
-	slls_free(pstate->popts->poutput_join_field_names);
-	hss_free(pstate->pleft_field_name_set);
-	hss_free(pstate->pright_field_name_set);
 
 	if (pstate->pleft_buckets_by_join_field_values != NULL) {
 		for (lhmslve_t* pe = pstate->pleft_buckets_by_join_field_values->phead; pe != NULL; pe = pe->pnext) {
@@ -261,7 +322,18 @@ static void mapper_join_free(mapper_t* pmapper) {
 	sllv_free(pstate->pleft_unpaired_records);
 
 	join_bucket_keeper_free(pstate->pjoin_bucket_keeper, pstate->popts->prepipe);
-	ap_free(pstate->pargp);
+
+	slls_free(pstate->popts->poutput_join_field_names);
+	slls_free(pstate->popts->pleft_join_field_names);
+	slls_free(pstate->popts->pright_join_field_names);
+
+	free(pstate->popts->output_join_field_names_cli_backing);
+	free(pstate->popts->left_join_field_names_cli_backing);
+	free(pstate->popts->right_join_field_names_cli_backing);
+
+	hss_free(pstate->pleft_field_name_set);
+	hss_free(pstate->pright_field_name_set);
+
 	free(pstate->popts);
 	free(pstate);
 	free(pmapper);
@@ -271,17 +343,6 @@ static void mapper_join_free(mapper_t* pmapper) {
 static sllv_t* mapper_join_process_sorted(lrec_t* pright_rec, context_t* pctx, void* pvstate) {
 	mapper_join_state_t* pstate = (mapper_join_state_t*)pvstate;
 
-	// This can't be done in the CLI-parser since it requires information which
-	// isn't known until after the CLI-parser is called.
-	if (pstate->pjoin_bucket_keeper == NULL) {
-		mapper_join_opts_t* popts = pstate->popts;
-		merge_options(&pstate->popts->reader_opts);
-		pstate->pjoin_bucket_keeper = join_bucket_keeper_alloc(
-			popts->prepipe,
-			popts->left_file_name,
-			&popts->reader_opts,
-			popts->pleft_join_field_names);
-	}
 	join_bucket_keeper_t* pkeeper = pstate->pjoin_bucket_keeper; // keystroke-saver
 
 	sllv_t* pleft_records = NULL;
@@ -457,77 +518,9 @@ static void mapper_join_form_pairs(sllv_t* pleft_records, lrec_t* pright_rec, ma
 	}
 }
 
-// ----------------------------------------------------------------
-// Format and separator flags are passed to mapper_join in MLR_GLOBALS rather
-// than on the stack, since the latter would require complicating the interface
-// for all the other mappers which don't do their own file I/O.  (Also, while
-// some of the information needed to construct an lrec_reader is available on
-// the command line before the mapper-allocators are called, some is not
-// available until after.  Hence our obtaining these flags after mapper-alloc.)
-//
-// Mainly this just takes the main-opts flag whenever the join-opts flag was not
-// specified by the user. But it's a bit more complex when main and join input
-// formats are different. Example: main input format is CSV, for which IPS is
-// "(N/A)", and join input format is DKVP. Then we should not use "(N/A)"
-// for DKVP IPS. However if main input format were DKVP with IPS set to ":",
-// then we should take that.
-//
-// The logic is:
-//
-// * If the join input format was unspecified, take all unspecified values from
-//   main opts.
-//
-// * If the join input format was specified and is the same as main input
-//   format, take unspecified values from main opts.
-//
-// * If the join input format was specified and is not the same as main input
-//   format, take unspecified values from defaults for the join input format.
-
-static void merge_options(cli_reader_opts_t* popts) {
-	if (popts->ifile_fmt == NULL) {
-		popts->ifile_fmt = MLR_GLOBALS.popts->reader_opts.ifile_fmt;
-	}
-
-	if (streq(popts->ifile_fmt, MLR_GLOBALS.popts->reader_opts.ifile_fmt)) {
-
-		if (popts->irs == NULL)
-			popts->irs = MLR_GLOBALS.popts->reader_opts.irs;
-		if (popts->ifs == NULL)
-			popts->ifs = MLR_GLOBALS.popts->reader_opts.ifs;
-		if (popts->ips == NULL)
-			popts->ips = MLR_GLOBALS.popts->reader_opts.ips;
-		if (popts->allow_repeat_ifs  == OPTION_UNSPECIFIED)
-			popts->allow_repeat_ifs = MLR_GLOBALS.popts->reader_opts.allow_repeat_ifs;
-		if (popts->allow_repeat_ips  == OPTION_UNSPECIFIED)
-			popts->allow_repeat_ips = MLR_GLOBALS.popts->reader_opts.allow_repeat_ips;
-
-	} else {
-
-		if (popts->irs == NULL)
-			popts->irs = lhmss_get(get_default_rses(), popts->ifile_fmt);
-		if (popts->ifs == NULL)
-			popts->ifs = lhmss_get(get_default_fses(), popts->ifile_fmt);
-		if (popts->ips == NULL)
-			popts->ips = lhmss_get(get_default_pses(), popts->ifile_fmt);
-		if (popts->allow_repeat_ifs  == OPTION_UNSPECIFIED)
-			popts->allow_repeat_ifs = lhmsi_get(get_default_repeat_ifses(), popts->ifile_fmt);
-		if (popts->allow_repeat_ips  == OPTION_UNSPECIFIED)
-			popts->allow_repeat_ips = lhmsi_get(get_default_repeat_ipses(), popts->ifile_fmt);
-
-	}
-
-	if (popts->use_implicit_csv_header == OPTION_UNSPECIFIED)
-		popts->use_implicit_csv_header = MLR_GLOBALS.popts->reader_opts.use_implicit_csv_header;
-	if (popts->use_mmap_for_read == OPTION_UNSPECIFIED)
-		popts->use_mmap_for_read = MLR_GLOBALS.popts->reader_opts.use_mmap_for_read;
-	if (popts->input_json_flatten_separator == NULL)
-		popts->input_json_flatten_separator = MLR_GLOBALS.popts->reader_opts.input_json_flatten_separator;
-}
-
 // ----------------------------------------------------------------
 static void ingest_left_file(mapper_join_state_t* pstate) {
 	mapper_join_opts_t* popts = pstate->popts;
-	merge_options(&popts->reader_opts);
 
 	lrec_reader_t* plrec_reader = lrec_reader_alloc(&popts->reader_opts);
 
