@@ -56,7 +56,8 @@ typedef struct _mapper_merge_fields_state_t {
 
 // ----------------------------------------------------------------
 static void      mapper_merge_fields_usage(FILE* o, char* argv0, char* verb);
-static mapper_t* mapper_merge_fields_parse_cli(int* pargi, int argc, char** argv);
+static mapper_t* mapper_merge_fields_parse_cli(int* pargi, int argc, char** argv,
+	cli_reader_opts_t* _, cli_writer_opts_t* __);
 static mapper_t* mapper_merge_fields_alloc(slls_t* paccumulator_names, merge_by_t do_which,
 	slls_t* pvalue_field_names, char* output_field_basename, int allow_int_float, int do_interpolated_percentiles,
 	int keep_input_fields);
@@ -105,7 +106,9 @@ static void mapper_merge_fields_usage(FILE* o, char* argv0, char* verb) {
 	fprintf(o, "  \"b_y\", and \"b_out_x\" collapses to \"b_x\".\n");
 }
 
-static mapper_t* mapper_merge_fields_parse_cli(int* pargi, int argc, char** argv) {
+static mapper_t* mapper_merge_fields_parse_cli(int* pargi, int argc, char** argv,
+	cli_reader_opts_t* _, cli_writer_opts_t* __)
+{
 	slls_t*    paccumulator_names          = NULL;
 	slls_t*    pvalue_field_names          = NULL;
 	char*      output_field_basename       = NULL;
