@@ -14,7 +14,62 @@
 #include "mapping/stats1_accumulators.h"
 
 // ----------------------------------------------------------------
-static int is_percentile_acc_name(char* stats1_acc_name) {
+void make_stats1_accs(
+	char*    value_field_name,            // input
+	slls_t*  paccumulator_names,          // input
+	int      allow_int_float,             // input
+	int      do_interpolated_percentiles, // input
+	lhmsv_t* acc_field_to_acc_state_in,   // output
+	lhmsv_t* acc_field_to_acc_state_out)  // output
+{
+	stats1_acc_t* ppercentile_acc = NULL;
+	for (sllse_t* pc = paccumulator_names->phead; pc != NULL; pc = pc->pnext) {
+		// for "sum", "count"
+		char* stats1_acc_name = pc->value;
+
+		// For percentiles there is one unique accumulator given (for example) five distinct
+		// names p0,p25,p50,p75,p100.  The input accumulators are unique: only one
+		// percentile-keeper. There are multiple output accumulators: each references the same
+		// underlying percentile-keeper but with distinct parameters.  Hence the "_in" and "_out" maps.
+		if (is_percentile_acc_name(stats1_acc_name)) {
+			if (ppercentile_acc == NULL) {
+				ppercentile_acc = stats1_percentile_alloc(value_field_name, stats1_acc_name, allow_int_float,
+					do_interpolated_percentiles);
+				if (ppercentile_acc == NULL) {
+					fprintf(stderr, "%s stats1: accumulator \"%s\" not found.\n",
+						MLR_GLOBALS.bargv0, stats1_acc_name);
+					exit(1);
+				}
+				lhmsv_put(acc_field_to_acc_state_in, stats1_acc_name, ppercentile_acc, NO_FREE);
+			} else {
+				stats1_percentile_reuse(ppercentile_acc);
+			}
+			lhmsv_put(acc_field_to_acc_state_out, stats1_acc_name, ppercentile_acc, NO_FREE);
+		} else {
+			stats1_acc_t* pstats1_acc = make_stats1_acc(value_field_name, stats1_acc_name, allow_int_float,
+				do_interpolated_percentiles);
+			if (pstats1_acc == NULL) {
+				fprintf(stderr, "%s stats1: accumulator \"%s\" not found.\n",
+					MLR_GLOBALS.bargv0, stats1_acc_name);
+				exit(1);
+			}
+			lhmsv_put(acc_field_to_acc_state_in, stats1_acc_name, pstats1_acc, NO_FREE);
+			lhmsv_put(acc_field_to_acc_state_out, stats1_acc_name, pstats1_acc, NO_FREE);
+		}
+	}
+}
+
+stats1_acc_t* make_stats1_acc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
+	for (int i = 0; i < stats1_acc_lookup_table_length; i++)
+		if (streq(stats1_acc_name, stats1_acc_lookup_table[i].name))
+			return stats1_acc_lookup_table[i].palloc_func(value_field_name, stats1_acc_name, allow_int_float,
+				do_interpolated_percentiles);
+	return NULL;
+}
+
+int is_percentile_acc_name(char* stats1_acc_name) {
 	double percentile;
 	// sscanf(stats1_acc_name, "p%lf", &percentile) allows "p74x" et al. which isn't ok.
 	if (stats1_acc_name[0] != 'p')
@@ -23,50 +78,12 @@ static int is_percentile_acc_name(char* stats1_acc_name) {
 		return FALSE;
 	if (percentile < 0.0 || percentile > 100.0) {
 		fprintf(stderr, "%s stats1: percentile \"%s\" outside range [0,100].\n",
-			MLR_GLOBALS.argv0, stats1_acc_name);
+			MLR_GLOBALS.bargv0, stats1_acc_name);
 		exit(1);
 	}
 	return TRUE;
 }
 
-// ----------------------------------------------------------------
-void make_stats1_accs(
-	char*      value_field_name,       // input
-	slls_t*    paccumulator_names,     // input
-	int        allow_int_float,        // input
-	lhmsv_t*   acc_field_to_acc_state) // output
-{
-	stats1_acc_t* ppercentile_acc = NULL;
-	for (sllse_t* pc = paccumulator_names->phead; pc != NULL; pc = pc->pnext) {
-		// for "sum", "count"
-		char* stats1_acc_name = pc->value;
-
-		if (is_percentile_acc_name(stats1_acc_name)) {
-			if (ppercentile_acc == NULL) {
-				ppercentile_acc = stats1_percentile_alloc(value_field_name, stats1_acc_name, allow_int_float);
-			} else {
-				stats1_percentile_reuse(ppercentile_acc);
-			}
-			lhmsv_put(acc_field_to_acc_state, stats1_acc_name, ppercentile_acc, NO_FREE);
-		} else {
-			stats1_acc_t* pstats1_acc = make_stats1_acc(value_field_name, stats1_acc_name, allow_int_float);
-			if (pstats1_acc == NULL) {
-				fprintf(stderr, "%s stats1: accumulator \"%s\" not found.\n",
-					MLR_GLOBALS.argv0, stats1_acc_name);
-				exit(1);
-			}
-			lhmsv_put(acc_field_to_acc_state, stats1_acc_name, pstats1_acc, NO_FREE);
-		}
-	}
-}
-
-stats1_acc_t* make_stats1_acc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
-	for (int i = 0; i < stats1_acc_lookup_table_length; i++)
-		if (streq(stats1_acc_name, stats1_acc_lookup_table[i].name))
-			return stats1_acc_lookup_table[i].palloc_func(value_field_name, stats1_acc_name, allow_int_float);
-	return NULL;
-}
-
 // ----------------------------------------------------------------
 typedef struct _stats1_count_state_t {
 	mv_t counter;
@@ -76,7 +93,7 @@ typedef struct _stats1_count_state_t {
 
 static void stats1_count_singest(void* pvstate, char* val) {
 	stats1_count_state_t* pstate = pvstate;
-	pstate->counter = n_nn_plus_func(&pstate->counter, &pstate->one);
+	pstate->counter = x_xx_plus_func(&pstate->counter, &pstate->one);
 
 }
 static void stats1_count_emit(void* pvstate, char* value_field_name, char* stats1_acc_name, int copy_data, lrec_t* poutrec) {
@@ -94,7 +111,9 @@ static void stats1_count_free(stats1_acc_t* pstats1_acc) {
 	free(pstate);
 	free(pstats1_acc);
 }
-stats1_acc_t* stats1_count_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_count_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	stats1_acc_t* pstats1_acc    = mlr_malloc_or_die(sizeof(stats1_acc_t));
 	stats1_count_state_t* pstate = mlr_malloc_or_die(sizeof(stats1_count_state_t));
 	pstate->counter              = allow_int_float ? mv_from_int(0LL) : mv_from_float(0.0);
@@ -149,7 +168,9 @@ static void stats1_mode_free(stats1_acc_t* pstats1_acc) {
 	free(pstate);
 	free(pstats1_acc);
 }
-stats1_acc_t* stats1_mode_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_mode_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	stats1_acc_t* pstats1_acc   = mlr_malloc_or_die(sizeof(stats1_acc_t));
 	stats1_mode_state_t* pstate = mlr_malloc_or_die(sizeof(stats1_mode_state_t));
 	pstate->pcounts_for_value   = lhmsi_alloc();
@@ -172,7 +193,7 @@ typedef struct _stats1_sum_state_t {
 } stats1_sum_state_t;
 static void stats1_sum_ningest(void* pvstate, mv_t* pval) {
 	stats1_sum_state_t* pstate = pvstate;
-	pstate->sum = n_nn_plus_func(&pstate->sum, pval);
+	pstate->sum = x_xx_plus_func(&pstate->sum, pval);
 }
 static void stats1_sum_emit(void* pvstate, char* value_field_name, char* stats1_acc_name, int copy_data, lrec_t* poutrec) {
 	stats1_sum_state_t* pstate = pvstate;
@@ -189,7 +210,9 @@ static void stats1_sum_free(stats1_acc_t* pstats1_acc) {
 	free(pstate);
 	free(pstats1_acc);
 }
-stats1_acc_t* stats1_sum_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_sum_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	stats1_acc_t* pstats1_acc  = mlr_malloc_or_die(sizeof(stats1_acc_t));
 	stats1_sum_state_t* pstate = mlr_malloc_or_die(sizeof(stats1_sum_state_t));
 	pstate->allow_int_float    = allow_int_float;
@@ -238,7 +261,9 @@ static void stats1_mean_free(stats1_acc_t* pstats1_acc) {
 	free(pstate);
 	free(pstats1_acc);
 }
-stats1_acc_t* stats1_mean_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_mean_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	stats1_acc_t* pstats1_acc   = mlr_malloc_or_die(sizeof(stats1_acc_t));
 	stats1_mean_state_t* pstate = mlr_malloc_or_die(sizeof(stats1_mean_state_t));
 	pstate->sum                 = 0.0;
@@ -313,13 +338,19 @@ stats1_acc_t* stats1_stddev_var_meaneb_alloc(char* value_field_name, char* stats
 	pstats1_acc->pfree_func    = stats1_stddev_var_meaneb_free;
 	return pstats1_acc;
 }
-stats1_acc_t* stats1_stddev_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_stddev_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	return stats1_stddev_var_meaneb_alloc(value_field_name, stats1_acc_name, DO_STDDEV);
 }
-stats1_acc_t* stats1_var_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_var_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	return stats1_stddev_var_meaneb_alloc(value_field_name, stats1_acc_name, DO_VAR);
 }
-stats1_acc_t* stats1_meaneb_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_meaneb_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	return stats1_stddev_var_meaneb_alloc(value_field_name, stats1_acc_name, DO_MEANEB);
 }
 
@@ -362,7 +393,9 @@ static void stats1_skewness_free(stats1_acc_t* pstats1_acc) {
 	free(pstats1_acc);
 }
 
-stats1_acc_t* stats1_skewness_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_skewness_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	stats1_acc_t* pstats1_acc = mlr_malloc_or_die(sizeof(stats1_acc_t));
 	stats1_skewness_state_t* pstate = mlr_malloc_or_die(sizeof(stats1_skewness_state_t));
 	pstate->count              = 0LL;
@@ -420,7 +453,9 @@ static void stats1_kurtosis_free(stats1_acc_t* pstats1_acc) {
 	free(pstate);
 	free(pstats1_acc);
 }
-stats1_acc_t* stats1_kurtosis_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_kurtosis_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	stats1_acc_t* pstats1_acc = mlr_malloc_or_die(sizeof(stats1_acc_t));
 	stats1_kurtosis_state_t* pstate = mlr_malloc_or_die(sizeof(stats1_kurtosis_state_t));
 	pstate->count              = 0LL;
@@ -445,7 +480,7 @@ typedef struct _stats1_min_state_t {
 } stats1_min_state_t;
 static void stats1_min_ningest(void* pvstate, mv_t* pval) {
 	stats1_min_state_t* pstate = pvstate;
-	pstate->min = n_nn_min_func(&pstate->min, pval);
+	pstate->min = x_xx_min_func(&pstate->min, pval);
 }
 static void stats1_min_emit(void* pvstate, char* value_field_name, char* stats1_acc_name, int copy_data, lrec_t* poutrec) {
 	stats1_min_state_t* pstate = pvstate;
@@ -469,10 +504,12 @@ static void stats1_min_free(stats1_acc_t* pstats1_acc) {
 	free(pstate);
 	free(pstats1_acc);
 }
-stats1_acc_t* stats1_min_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_min_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	stats1_acc_t* pstats1_acc  = mlr_malloc_or_die(sizeof(stats1_acc_t));
 	stats1_min_state_t* pstate = mlr_malloc_or_die(sizeof(stats1_min_state_t));
-	pstate->min                = mv_from_null();
+	pstate->min                = mv_absent();
 	pstate->output_field_name  = mlr_paste_3_strings(value_field_name, "_", stats1_acc_name);
 
 	pstats1_acc->pvstate       = (void*)pstate;
@@ -491,7 +528,7 @@ typedef struct _stats1_max_state_t {
 } stats1_max_state_t;
 static void stats1_max_ningest(void* pvstate, mv_t* pval) {
 	stats1_max_state_t* pstate = pvstate;
-	pstate->max = n_nn_max_func(&pstate->max, pval);
+	pstate->max = x_xx_max_func(&pstate->max, pval);
 }
 static void stats1_max_emit(void* pvstate, char* value_field_name, char* stats1_acc_name, int copy_data, lrec_t* poutrec) {
 	stats1_max_state_t* pstate = pvstate;
@@ -515,10 +552,12 @@ static void stats1_max_free(stats1_acc_t* pstats1_acc) {
 	free(pstate);
 	free(pstats1_acc);
 }
-stats1_acc_t* stats1_max_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_max_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	stats1_acc_t* pstats1_acc  = mlr_malloc_or_die(sizeof(stats1_acc_t));
 	stats1_max_state_t* pstate = mlr_malloc_or_die(sizeof(stats1_max_state_t));
-	pstate->max                = mv_from_null();
+	pstate->max                = mv_absent();
 	pstate->output_field_name  = mlr_paste_3_strings(value_field_name, "_", stats1_acc_name);
 
 	pstats1_acc->pvstate       = (void*)pstate;
@@ -535,6 +574,7 @@ typedef struct _stats1_percentile_state_t {
 	percentile_keeper_t* ppercentile_keeper;
 	lhmss_t* poutput_field_names;
 	int reference_count;
+	percentile_keeper_emitter_t* ppercentile_keeper_emitter;
 } stats1_percentile_state_t;
 static void stats1_percentile_ningest(void* pvstate, mv_t* pval) {
 	stats1_percentile_state_t* pstate = pvstate;
@@ -545,7 +585,7 @@ static void stats1_percentile_emit(void* pvstate, char* value_field_name, char*
 
 	double p;
 	(void)sscanf(stats1_acc_name, "p%lf", &p); // Assuming this was range-checked earlier on to be in [0,100].
-	mv_t v = percentile_keeper_emit(pstate->ppercentile_keeper, p);
+	mv_t v = pstate->ppercentile_keeper_emitter(pstate->ppercentile_keeper, p);
 	char* s = mv_alloc_format_val(&v);
 	// For this type, one accumulator tracks many stats1_names, but a single value_field_name.
 	char* output_field_name = lhmss_get(pstate->poutput_field_names, stats1_acc_name);
@@ -566,12 +606,17 @@ static void stats1_percentile_free(stats1_acc_t* pstats1_acc) {
 		free(pstats1_acc);
 	}
 }
-stats1_acc_t* stats1_percentile_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float) {
+stats1_acc_t* stats1_percentile_alloc(char* value_field_name, char* stats1_acc_name, int allow_int_float,
+	int do_interpolated_percentiles)
+{
 	stats1_acc_t* pstats1_acc   = mlr_malloc_or_die(sizeof(stats1_acc_t));
 	stats1_percentile_state_t* pstate = mlr_malloc_or_die(sizeof(stats1_percentile_state_t));
 	pstate->ppercentile_keeper  = percentile_keeper_alloc();
 	pstate->poutput_field_names = lhmss_alloc();
 	pstate->reference_count     = 1;
+	pstate->ppercentile_keeper_emitter = (do_interpolated_percentiles)
+		? percentile_keeper_emit_linearly_interpolated
+		: percentile_keeper_emit_non_interpolated;
 
 	pstats1_acc->pvstate        = (void*)pstate;
 	pstats1_acc->pdingest_func  = NULL;
