@@ -8,7 +8,7 @@ typedef struct _lrec_writer_nidx_state_t {
 } lrec_writer_nidx_state_t;
 
 static void lrec_writer_nidx_free(lrec_writer_t* pwriter);
-static void lrec_writer_nidx_process(FILE* output_stream, lrec_t* prec, void* pvstate);
+static void lrec_writer_nidx_process(void* pvstate, FILE* output_stream, lrec_t* prec);
 
 // ----------------------------------------------------------------
 lrec_writer_t* lrec_writer_nidx_alloc(char* ors, char* ofs) {
@@ -31,7 +31,7 @@ static void lrec_writer_nidx_free(lrec_writer_t* pwriter) {
 }
 
 // ----------------------------------------------------------------
-static void lrec_writer_nidx_process(FILE* output_stream, lrec_t* prec, void* pvstate) {
+static void lrec_writer_nidx_process(void* pvstate, FILE* output_stream, lrec_t* prec) {
 	if (prec == NULL)
 		return;
 	lrec_writer_nidx_state_t* pstate = pvstate;
