@@ -16,7 +16,7 @@ lrec_writer_t* lrec_writer_dkvp_alloc(char* ors, char* ofs, char* ops);
 lrec_writer_t* lrec_writer_json_alloc(int stack_vertically, int wrap_json_output_in_outer_list,
 	int quote_json_values_always, char* output_json_flatten_separator);
 lrec_writer_t* lrec_writer_nidx_alloc(char* ors, char* ofs);
-lrec_writer_t* lrec_writer_pprint_alloc(char* ors, char ofs, int left_align);
+lrec_writer_t* lrec_writer_pprint_alloc(char* ors, char ofs, int right_align);
 lrec_writer_t* lrec_writer_xtab_alloc(char* ofs, char* ops, int right_justify_value);
 
 // Pops and frees the lrecs in the argument list without sllv-freeing the list structure itself.
