@@ -12,6 +12,8 @@
 #include "containers/lhmsv.h"
 #include "containers/lhms2v.h"
 #include "containers/lhmslv.h"
+#include "containers/lhmsmv.h"
+#include "containers/bind_stack.h"
 #include "containers/percentile_keeper.h"
 #include "containers/top_keeper.h"
 #include "containers/dheap.h"
@@ -21,6 +23,17 @@ int tests_failed      = 0;
 int assertions_run    = 0;
 int assertions_failed = 0;
 
+static mv_t* smv(char* strv) {
+	mv_t* pmv = mlr_malloc_or_die(sizeof(mv_t));
+	*pmv = mv_from_string(strv, NO_FREE);
+	return pmv;
+}
+static mv_t* imv(long long intv) {
+	mv_t* pmv = mlr_malloc_or_die(sizeof(mv_t));
+	*pmv = mv_from_int(intv);
+	return pmv;
+}
+
 // ----------------------------------------------------------------
 static char* test_slls() {
 	slls_t* plist = slls_from_line(mlr_strdup_or_die(""), ',', FALSE);
@@ -60,9 +73,9 @@ static char* test_slls() {
 static char* test_rslls() {
 
 	rslls_t* pa = rslls_alloc();
-	rslls_append_no_free(pa, "a");
-	rslls_append_no_free(pa, "b");
-	rslls_append_no_free(pa, "c");
+	rslls_append(pa, "a", NO_FREE, 0);
+	rslls_append(pa, "b", NO_FREE, 0);
+	rslls_append(pa, "c", NO_FREE, 0);
 
 	rslls_print(pa); printf("\n");
 	mu_assert_lf(pa->length == 3);
@@ -82,7 +95,7 @@ static char* test_rslls() {
 	mu_assert_lf(pe != NULL); mu_assert_lf(pe->value == NULL); pe = pe->pnext;
 	mu_assert_lf(pe == NULL);
 
-	rslls_append_no_free(pa, "d");
+	rslls_append(pa, "d", NO_FREE, 0);
 
 	rslls_print(pa); printf("\n");
 	mu_assert_lf(pa->length == 1);
@@ -92,7 +105,7 @@ static char* test_rslls() {
 	mu_assert_lf(pe != NULL); mu_assert_lf(pe->value == NULL); pe = pe->pnext;
 	mu_assert_lf(pe == NULL);
 
-	rslls_append_no_free(pa, "e");
+	rslls_append(pa, "e", NO_FREE, 0);
 
 	rslls_print(pa); printf("\n");
 	mu_assert_lf(pa->length == 2);
@@ -102,7 +115,7 @@ static char* test_rslls() {
 	mu_assert_lf(pe != NULL); mu_assert_lf(pe->value == NULL); pe = pe->pnext;
 	mu_assert_lf(pe == NULL);
 
-	rslls_append_no_free(pa, "f");
+	rslls_append(pa, "f", NO_FREE, 0);
 
 	rslls_print(pa); printf("\n");
 	mu_assert_lf(pa->length == 3);
@@ -112,7 +125,7 @@ static char* test_rslls() {
 	mu_assert_lf(pe != NULL); mu_assert_lf(streq(pe->value, "f")); pe = pe->pnext;
 	mu_assert_lf(pe == NULL);
 
-	rslls_append_no_free(pa, "g");
+	rslls_append(pa, "g", NO_FREE, 0);
 
 	rslls_print(pa); printf("\n");
 	mu_assert_lf(pa->length == 4);
@@ -499,6 +512,142 @@ static char* test_lhmslv() {
 	return NULL;
 }
 
+// ----------------------------------------------------------------
+static char* test_lhmsmv() {
+	printf("\n");
+
+	lhmsmv_t *pmap = lhmsmv_alloc();
+	mu_assert_lf(pmap->num_occupied == 0);
+	mu_assert_lf(!lhmsmv_has_key(pmap, "w")); mu_assert_lf(lhmsmv_get(pmap, "w") == NULL);
+	mu_assert_lf(!lhmsmv_has_key(pmap, "x")); mu_assert_lf(lhmsmv_get(pmap, "x") == NULL);
+	mu_assert_lf(!lhmsmv_has_key(pmap, "y")); mu_assert_lf(lhmsmv_get(pmap, "y") == NULL);
+	mu_assert_lf(!lhmsmv_has_key(pmap, "z")); mu_assert_lf(lhmsmv_get(pmap, "z") == NULL);
+	mu_assert_lf(lhmsmv_check_counts(pmap));
+
+	lhmsmv_put(pmap, "x", imv(3), NO_FREE);
+	lhmsmv_dump(pmap);
+	printf("\n");
+	mu_assert_lf(pmap->num_occupied == 1);
+	mu_assert_lf(!lhmsmv_has_key(pmap, "w")); mu_assert_lf(lhmsmv_get(pmap, "w") == NULL);
+	mu_assert_lf( lhmsmv_has_key(pmap, "x")); mu_assert_lf(mveq(lhmsmv_get(pmap, "x"), imv(3)));
+	mu_assert_lf( lhmsmv_has_key(pmap, "x")); mu_assert_lf(mveq(lhmsmv_get(pmap, "x"), smv("3")));
+	mu_assert_lf(!lhmsmv_has_key(pmap, "y")); mu_assert_lf(lhmsmv_get(pmap, "y") == NULL);
+	mu_assert_lf(!lhmsmv_has_key(pmap, "z")); mu_assert_lf(lhmsmv_get(pmap, "z") == NULL);
+	mu_assert_lf(lhmsmv_check_counts(pmap));
+
+	lhmsmv_put(pmap, "y", smv("5"), NO_FREE);
+	lhmsmv_dump(pmap);
+	printf("\n");
+	mu_assert_lf(pmap->num_occupied == 2);
+	mu_assert_lf(!lhmsmv_has_key(pmap, "w")); mu_assert_lf(lhmsmv_get(pmap, "w") == NULL);
+	mu_assert_lf( lhmsmv_has_key(pmap, "x")); mu_assert_lf(mveq(lhmsmv_get(pmap, "x"), smv("3")));
+	mu_assert_lf( lhmsmv_has_key(pmap, "y")); mu_assert_lf(mveq(lhmsmv_get(pmap, "y"), smv("5")));
+	mu_assert_lf( lhmsmv_has_key(pmap, "y")); mu_assert_lf(mveq(lhmsmv_get(pmap, "y"), imv(5)));
+	mu_assert_lf(!lhmsmv_has_key(pmap, "z")); mu_assert_lf(lhmsmv_get(pmap, "z") == NULL);
+	mu_assert_lf(lhmsmv_check_counts(pmap));
+
+	lhmsmv_put(pmap, "x", smv("f"), NO_FREE);
+	lhmsmv_dump(pmap);
+	printf("\n");
+	mu_assert_lf(pmap->num_occupied == 2);
+	mu_assert_lf(!lhmsmv_has_key(pmap, "w")); mu_assert_lf(lhmsmv_get(pmap, "w") == NULL);
+	mu_assert_lf( lhmsmv_has_key(pmap, "x")); mu_assert_lf(mveq(lhmsmv_get(pmap, "x"), smv("f")));
+	mu_assert_lf( lhmsmv_has_key(pmap, "y")); mu_assert_lf(mveq(lhmsmv_get(pmap, "y"), smv("5")));
+	mu_assert_lf(!lhmsmv_has_key(pmap, "z")); mu_assert_lf(lhmsmv_get(pmap, "z") == NULL);
+	mu_assert_lf(lhmsmv_check_counts(pmap));
+
+	lhmsmv_put(pmap, "z", imv(7), NO_FREE);
+	lhmsmv_dump(pmap);
+	printf("\n");
+	mu_assert_lf(pmap->num_occupied == 3);
+	mu_assert_lf(!lhmsmv_has_key(pmap, "w")); mu_assert_lf(lhmsmv_get(pmap, "w") == NULL);
+	mu_assert_lf( lhmsmv_has_key(pmap, "x")); mu_assert_lf(mveq(lhmsmv_get(pmap, "x"), smv("f")));
+	mu_assert_lf( lhmsmv_has_key(pmap, "y")); mu_assert_lf(mveq(lhmsmv_get(pmap, "y"), smv("5")));
+	mu_assert_lf( lhmsmv_has_key(pmap, "y")); mu_assert_lf(mveq(lhmsmv_get(pmap, "y"), imv(5)));
+	mu_assert_lf( lhmsmv_has_key(pmap, "z")); mu_assert_lf(mveq(lhmsmv_get(pmap, "z"), smv("7")));
+	mu_assert_lf( lhmsmv_has_key(pmap, "z")); mu_assert_lf(mveq(lhmsmv_get(pmap, "z"), imv(7)));
+	mu_assert_lf(lhmsmv_check_counts(pmap));
+
+	lhmsmv_free(pmap);
+
+	return NULL;
+}
+
+// ----------------------------------------------------------------
+static char* test_bind_stack() {
+	printf("\n");
+
+	//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+	bind_stack_t* pstack = bind_stack_alloc();
+	bind_stack_print(pstack);
+
+	mu_assert_lf(bind_stack_resolve(pstack, "x") == NULL);
+
+	//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+	lhmsmv_t* pframe0 = lhmsmv_alloc();
+	bind_stack_push(pstack, pframe0);
+	bind_stack_print(pstack);
+
+	lhmsmv_put(pframe0, "x", smv("1"), NO_FREE);
+	lhmsmv_put(pframe0, "y", smv("2"), NO_FREE);
+	bind_stack_print(pstack);
+
+	mu_assert_lf(bind_stack_resolve(pstack, "x") != NULL);
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "x"), smv("1")));
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "x"), imv(1)));
+	mu_assert_lf(bind_stack_resolve(pstack, "y") != NULL);
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "y"), smv("2")));
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "y"), imv(2)));
+	mu_assert_lf(bind_stack_resolve(pstack, "z") == NULL);
+
+	//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+	lhmsmv_t* pframe1 = lhmsmv_alloc();
+	bind_stack_push(pstack, pframe1);
+	bind_stack_print(pstack);
+
+	//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+	lhmsmv_t* pframe2 = lhmsmv_alloc();
+	bind_stack_push(pstack, pframe2);
+	bind_stack_print(pstack);
+
+	mu_assert_lf(bind_stack_resolve(pstack, "x") != NULL);
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "x"), smv("1")));
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "x"), imv(1)));
+	mu_assert_lf(bind_stack_resolve(pstack, "y") != NULL);
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "y"), smv("2")));
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "y"), imv(2)));
+	mu_assert_lf(bind_stack_resolve(pstack, "z") == NULL);
+
+	lhmsmv_put(pframe2, "x", smv("three"), NO_FREE);
+	bind_stack_print(pstack);
+
+	mu_assert_lf(bind_stack_resolve(pstack, "x") != NULL);
+	mu_assert_lf(!mveq(bind_stack_resolve(pstack, "x"), smv("1")));
+	mu_assert_lf(!mveq(bind_stack_resolve(pstack, "x"), imv(1)));
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "x"), smv("three")));
+	mu_assert_lf(bind_stack_resolve(pstack, "y") != NULL);
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "y"), smv("2")));
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "y"), imv(2)));
+	mu_assert_lf(bind_stack_resolve(pstack, "z") == NULL);
+
+	//  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+	bind_stack_pop(pstack);
+	bind_stack_print(pstack);
+
+	mu_assert_lf(bind_stack_resolve(pstack, "x") != NULL);
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "x"), smv("1")));
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "x"), imv(1)));
+	mu_assert_lf(bind_stack_resolve(pstack, "y") != NULL);
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "y"), smv("2")));
+	mu_assert_lf(mveq(bind_stack_resolve(pstack, "y"), imv(2)));
+	mu_assert_lf(bind_stack_resolve(pstack, "z") == NULL);
+
+	bind_stack_free(pstack);
+
+	printf("\n");
+	return NULL;
+}
+
 // ----------------------------------------------------------------
 static char* test_percentile_keeper() {
 
@@ -513,31 +662,31 @@ static char* test_percentile_keeper() {
 	double p;
 	mv_t q;
 	p = 0.0;
-	q = percentile_keeper_emit(ppercentile_keeper, p);
+	q = percentile_keeper_emit_non_interpolated(ppercentile_keeper, p);
 	printf("%4.2lf -> %7.4lf\n", p, q.u.fltv);
 	mu_assert_lf(q.type == MT_FLOAT);
 	mu_assert_lf(q.u.fltv == 1.0);
 
 	p = 10.0;
-	q = percentile_keeper_emit(ppercentile_keeper, p);
+	q = percentile_keeper_emit_non_interpolated(ppercentile_keeper, p);
 	printf("%4.2lf -> %7.4lf\n", p, q.u.fltv);
 	mu_assert_lf(q.type == MT_FLOAT);
 	mu_assert_lf(q.u.fltv == 1.0);
 
 	p = 50.0;
-	q = percentile_keeper_emit(ppercentile_keeper, p);
+	q = percentile_keeper_emit_non_interpolated(ppercentile_keeper, p);
 	printf("%4.2lf -> %lld\n", p, q.u.intv);
 	mu_assert_lf(q.type == MT_INT);
 	mu_assert_lf(q.u.intv == 3LL);
 
 	p = 90.0;
-	q = percentile_keeper_emit(ppercentile_keeper, p);
+	q = percentile_keeper_emit_non_interpolated(ppercentile_keeper, p);
 	printf("%4.2lf -> %7.4lf\n", p, q.u.fltv);
 	mu_assert_lf(q.type == MT_FLOAT);
 	mu_assert_lf(q.u.fltv == 5.0);
 
 	p = 100.0;
-	q = percentile_keeper_emit(ppercentile_keeper, p);
+	q = percentile_keeper_emit_non_interpolated(ppercentile_keeper, p);
 	printf("%4.2lf -> %7.4lf\n", p, q.u.fltv);
 	mu_assert_lf(q.type == MT_FLOAT);
 	mu_assert_lf(q.u.fltv == 5.0);
@@ -684,6 +833,8 @@ static char * run_all_tests() {
 	mu_run_test(test_lhmsv);
 	mu_run_test(test_lhms2v);
 	mu_run_test(test_lhmslv);
+	mu_run_test(test_lhmsmv);
+	mu_run_test(test_bind_stack);
 	mu_run_test(test_percentile_keeper);
 	mu_run_test(test_top_keeper);
 	mu_run_test(test_dheap);
